@@ -3,8 +3,8 @@
 # flake8: noqa
 
 
-# from onepasswordconnectsdkopexe.config import load
-# from onepasswordconnectsdkopexe.config import load_dict
+from onepasswordconnectsdkopexe.config import load
+from onepasswordconnectsdkopexe.config import load_dict
 from onepasswordconnectsdkopexe.client import new_client
 # from onepasswordconnectsdkopexe.client import new_client_from_environment
 from onepasswordconnectsdkopexe.client import new_client_interactif
